# __init__.py
from .email_without_attachment import email_without_attachment
from .display_email import display_email
from .display_email_with_attachments import display_email_with_attachments
from .email_with_attachments import email_with_attachments
from .notify_error import notify_error
from .default_table_style import default_table_style
# Version of the package
__version__ = "1.3"
